# FILE: mag2hfield.tcl
#
# This file must be interpreted by the mmsolve shell.

package require Oc 1.1
package require Mms 1.1.1

Oc_Main SetAppName mag2hfield
Oc_Main SetVersion 1.1.1.0

Oc_CommandLine Option console {} {}

Oc_CommandLine Option fieldstep {
	{index {regexp {^[0-9]+$} $index} {is a decimal integer}} 
    } {
	global fieldstep_request; scan $index %d fieldstep_request
} {Which applied field step to use (default=0)}
set fieldstep_request 0   ;# Default field step

Oc_CommandLine Option component {
	{request {
		foreach _ [split $request ,] {
		    if {![regexp all|anis|applied|demag|exchange|total $_]} {
			return 0
		    }
		}
		return 1
	} "is subset of\n                             \
		{all,anis,applied,demag,exchange,total}"}
    } {
	global component_request;  set component_request [split $request ,]
	if {[lsearch -exact $component_request all] != -1} {
	    set component_request [list anis applied demag exchange total]
	}
} {Which H fields to compute}
set component_request "total"   ;# Default field component output

Oc_CommandLine Option [Oc_CommandLine Switch] {
	{mif_file {} {Problem specification file (MIF)}}
	{omf_file {} {Magnetization state file}}
    } {
	upvar #0 mif_file globalmif_file; set globalmif_file $mif_file
	upvar #0 omf_file globalomf_file; set globalomf_file $omf_file
} {End of options; next argument is mif_file}

Oc_CommandLine Parse $argv

if {[string match {*.mif} $omf_file] || \
	[string match {*.omf} $mif_file]} {
    puts stderr "Warning: Are .mif and .omf files in correct order?"
    puts stderr "   (.mif should be first.)"
}

mms_mif New mif
$mif Read $mif_file
$mif SetMagInitArgs "avffile $omf_file"

mms_solver New solver $mif
$solver IncrementFieldStep $fieldstep_request

regsub {(\.omf|\.ovf)$} $omf_file {} basename
set heff_file ${basename}.ovf

puts -nonewline "  Writing"
foreach component $component_request {
    set component [string tolower $component]
    set out_file "${basename}-h${component}.ohf"
    puts -nonewline " $out_file"
    flush stdout
    $solver WriteFieldComponentFile $component $out_file \
	    "$component field component from $mif_file + $omf_file"
}
puts {}
flush stdout

catch { $solver Delete }
catch { $mif Delete }

# Without this, -tk 1 keeps grey box forever.
exit 0

